@@ -1,13 +1,11 @@
 ## ----include = FALSE----------------------------------------------------------
-env_present <- slendr::check_dependencies(python = TRUE)
-
 knitr::opts_chunk$set(
   collapse = FALSE,
   comment = "#>",
-  eval = env_present,
   fig.width = 6,
   fig.height = 4,
-  dpi = 70
+  dpi = 60,
+  eval = slendr::check_dependencies(python = TRUE)
 )
 
 ## -----------------------------------------------------------------------------
