@@ -2,7 +2,8 @@ map <- readRDS("map.rds")
 pop <- population("pop1", N = 100, time = 100,
                   center = c(0, 25), radius = 100000, map = map, intersect = FALSE)
 model <- compile_model(
-  pop, path = tempfile(), generation_time = 1, resolution = 100000,
+  pop, path = normalizePath(tempfile(), winslash = "/", mustWork = FALSE),
+  generation_time = 1, resolution = 100000,
   competition = 100e3, mating = 100e3, dispersal = 10e3,
   direction = "backward"
 )
