@@ -1,4 +1,4 @@
-skip_if(!is_slendr_env_present())
+skip_if(!check_dependencies(python = TRUE))
 
 # Run a given forward/backward simulation with different combinations
 # of start-end and burnin parameters
