@@ -1,4 +1,6 @@
-skip_if(!is_slendr_env_present())
+# skip_if(TRUE)
+
+skip_if(!check_dependencies(python = TRUE))
 init_env(quiet = TRUE)
 
 test_that("forward and backward time model objects are equivalent", {
